@@ -27,5 +27,7 @@ from identitylib.card_client.model.inline_response2003 import InlineResponse2003
 from identitylib.card_client.model.inline_response2004 import InlineResponse2004
 from identitylib.card_client.model.inline_response2005 import InlineResponse2005
 from identitylib.card_client.model.inline_response2006 import InlineResponse2006
+from identitylib.card_client.model.inline_response2007 import InlineResponse2007
+from identitylib.card_client.model.inline_response2007_results import InlineResponse2007Results
 from identitylib.card_client.model.v1beta1_card_requests_id_identifiers import V1beta1CardRequestsIdIdentifiers
 from identitylib.card_client.model.validation_error import ValidationError
